==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/en/topic.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'add_bookmark'=>'Add a bookmark',
'add_to_blacklist'=>'Add author to blacklist',
'back_to_search_results'=>'Back to search results',
'close_topic'=>'Close topic',
'delete_post'=>'Delete',
'delete_report_posting_request'=>'I checked this posting and remove the "Posting Report Request"...',
'deny_by_topic_acl'=>'You are not allowed to read this topic as you were rejected by its access control list',
'edit_post'=>'Edit',
'edit_profile'=>'Edit user account',
'link_to_this_posting'=>'Permanent-Link',
'moderation'=>'Moderation',
'open_topic'=>'Open topic',
'other_topics_related_to_owner'=>'The topic starter also wrote',
'other_topics_related_to_subject'=>'These topics are related',
'posting_edited_by'=>'Edited by',
'posting_edited_reason'=>'Reason',
'posting_has_been_ignored'=>'The author of this posting is located on your blacklist and therefore you cannot see his message.',
'posting_invisible'=>'Note: This posting is unapproved and invisible to common users.',
'posting_see_ignored_either'=>'Show the message anyway',
'post_new_reply'=>'Post new reply',
'post_quoted_reply'=>'Quote',
'purge_post_cache'=>'Purge Posting Cache',
'purge_topic_cache'=>'Purge Topic Cache',
'remove_bookmark'=>'Remove this bookmark',
'remove_from_blacklist'=>'Remove author from blacklist',
'report_posting'=>'Report Posting',
'set_post_hidden'=>'Set hidden',
'set_post_visible'=>'Set visible',
'topic_view'=>'Topic View'
);
?>

==> larus_board-1.2.0.zip: larus_board-1.2.0/lb_private/lang/en/topic.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'add_bookmark'=>'Add a bookmark',
'add_to_blacklist'=>'Add author to blacklist',
'back_to_search_results'=>'Back to search results',
'close_topic'=>'Close topic',
'delete_post'=>'Delete',
'delete_report_posting_request'=>'I checked this posting and remove the "Posting Report Request"...',
'deny_by_topic_acl'=>'You are not allowed to read this topic as you were rejected by its access control list',
'edit_post'=>'Edit',
'link_to_this_posting'=>'Permanent-Link',
'moderation'=>'Moderation',
'open_topic'=>'Open topic',
'other_topics_related_to_owner'=>'The topic starter also wrote',
'other_topics_related_to_subject'=>'These topics are related',
'posting_edited_by'=>'Edited by',
'posting_edited_reason'=>'Reason',
'posting_has_been_ignored'=>'The author of this posting is located on your blacklist and therefore you cannot see his message.',
'posting_invisible'=>'Note: This posting is unapproved and invisible to common users.',
'posting_see_ignored_either'=>'Show the message anyway',
'post_new_reply'=>'Post new reply',
'post_quoted_reply'=>'Quote',
'purge_post_cache'=>'Purge Posting Cache',
'purge_topic_cache'=>'Purge Topic Cache',
'remove_bookmark'=>'Remove this bookmark',
'remove_from_blacklist'=>'Remove author from blacklist',
'report_posting'=>'Report Posting',
'set_post_hidden'=>'Set hidden',
'set_post_visible'=>'Set visible',
'topic_is_pending_request'=>'This topic is a pending request. As soon as it is finished, you should close the topic. Then it will not be listed any longer.',
'topic_view'=>'Topic View'
);
?>
